==> alliance-5.0-20020701.tar.gz: alliance-5.0/xvpn/src/XSB_error.h <==
/*------------------------------------------------------------\
|                                                             |
| This file is part of the Alliance CAD System Copyright      |
| (C) Laboratoire LIP6 - Dpartement ASIM Universite P&M Curie|
|                                                             |
| Home page      : http://www-asim.lip6.fr/alliance/          |
| E-mail support : mailto:alliance-support@asim.lip6.fr       |
|                                                             |
| This progam is  free software; you can redistribute it      |
| and/or modify it under the  terms of the GNU General Public |
| License as  published by the Free Software Foundation;      |
| either version 2 of the License, or (at your option) any    |
| later version.                                              |
|                                                             |
| Alliance VLSI  CAD System  is distributed  in the hope that |
| it  will be useful, but WITHOUT  ANY WARRANTY;              |
| without even the  implied warranty of MERCHANTABILITY or    |
| FITNESS FOR A PARTICULAR PURPOSE. See the GNU General       |
| Public License for more details.                            |
|                                                             |
| You should have received a copy  of the GNU General Public  |
| License along with the GNU C Library; see the file COPYING. |
| If not, write to the Free Software Foundation, Inc.,        |
| 675 Mass Ave, Cambridge, MA 02139, USA.                     |
|                                                             |
\------------------------------------------------------------*/

/*------------------------------------------------------------\
|                                                             |
| Tool    :                   XVPN                           |
|                                                             |
| File    :                 Xsb Errors                        |
|                                                             |
| Authors :                Jacomme Ludovic                    |
|                                                             |
| Date    :                   04.12.96                        |
|                                                             |
\------------------------------------------------------------*/

/*------------------------------------------------------------\
|                                                             |
|                           Constants                         |
|                                                             |
\------------------------------------------------------------*/

# ifndef XSB_ERROR
# define XSB_ERROR

/*------------------------------------------------------------\
|                                                             |
|                       Rpr Error Constants                   |
|                                                             |
\------------------------------------------------------------*/

# define DEFINE_MISSING  0 
# define TABLE_MISSING   1 
# define LINE_EXPECTED   2
# define UNKNOWN_DEFINE  3 
# define NOT_DEFINED     4 
# define TOO_SMAL        5
# define MISSING_VALUE   6
# define MISSING_NAME    7
# define UNEXPECTED_LINE 8 
# define UNEXPECTED_EOF  9 
# define TOO_MANY_WORDS  10
# define MISSING_TABLE   11
# define OPEN_FILE       12
# define UNKNOWN_TABLE   13
# define SYNTAX_ERROR    14
# define ILLEGAL_FLOAT   15
# define FREE_ERROR      16
# define ALLOC_ERROR     17

/*------------------------------------------------------------\
|                                                             |
|                            Types                            |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                          Variables                          |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                          Functions                          |
|                                                             |
\------------------------------------------------------------*/

  extern void XsbError();

# endif

==> alliance_5.0-20110203.orig.tar.gz: alliance-5.0/xvpn/src/XSB_error.h <==
/*------------------------------------------------------------\
|                                                             |
| This file is part of the Alliance CAD System Copyright      |
| (C) Laboratoire LIP6 - Dpartement ASIM Universite P&M Curie|
|                                                             |
| Home page      : http://www-asim.lip6.fr/alliance/          |
| E-mail         : mailto:alliance-users@asim.lip6.fr       |
|                                                             |
| This progam is  free software; you can redistribute it      |
| and/or modify it under the  terms of the GNU General Public |
| License as  published by the Free Software Foundation;      |
| either version 2 of the License, or (at your option) any    |
| later version.                                              |
|                                                             |
| Alliance VLSI  CAD System  is distributed  in the hope that |
| it  will be useful, but WITHOUT  ANY WARRANTY;              |
| without even the  implied warranty of MERCHANTABILITY or    |
| FITNESS FOR A PARTICULAR PURPOSE. See the GNU General       |
| Public License for more details.                            |
|                                                             |
| You should have received a copy  of the GNU General Public  |
| License along with the GNU C Library; see the file COPYING. |
| If not, write to the Free Software Foundation, Inc.,        |
| 675 Mass Ave, Cambridge, MA 02139, USA.                     |
|                                                             |
\------------------------------------------------------------*/

/*------------------------------------------------------------\
|                                                             |
| Tool    :                   XVPN                           |
|                                                             |
| File    :                 Xsb Errors                        |
|                                                             |
| Authors :                Jacomme Ludovic                    |
|                                                             |
| Date    :                   04.12.96                        |
|                                                             |
\------------------------------------------------------------*/

/*------------------------------------------------------------\
|                                                             |
|                           Constants                         |
|                                                             |
\------------------------------------------------------------*/

# ifndef XSB_ERROR
# define XSB_ERROR

/*------------------------------------------------------------\
|                                                             |
|                       Rpr Error Constants                   |
|                                                             |
\------------------------------------------------------------*/

# define DEFINE_MISSING  0 
# define TABLE_MISSING   1 
# define LINE_EXPECTED   2
# define UNKNOWN_DEFINE  3 
# define NOT_DEFINED     4 
# define TOO_SMAL        5
# define MISSING_VALUE   6
# define MISSING_NAME    7
# define UNEXPECTED_LINE 8 
# define UNEXPECTED_EOF  9 
# define TOO_MANY_WORDS  10
# define MISSING_TABLE   11
# define OPEN_FILE       12
# define UNKNOWN_TABLE   13
# define SYNTAX_ERROR    14
# define ILLEGAL_FLOAT   15
# define FREE_ERROR      16
# define ALLOC_ERROR     17

/*------------------------------------------------------------\
|                                                             |
|                            Types                            |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                          Variables                          |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                          Functions                          |
|                                                             |
\------------------------------------------------------------*/

  extern void XsbError();

# endif
